@@ -1,21 +1,12 @@
 package CGI::Fast;
 use strict;
+use warnings;
 use if $] >= 5.019, 'deprecate';
 
-# A way to say "use warnings" that's compatible with even older perls.
-# making it local will not affect the code that loads this module
-# and since we're not in a BLOCK, warnings are enabled until the EOF
-local $^W = 1;
-
-# Copyright 1995,1996, Lincoln D. Stein.  All rights reserved.
-# It may be used and modified freely, but I do request that this copyright
-# notice remain attached to the file.  You may modify this module as you
-# wish, but if you redistribute a modified version, please attach a note
-# listing the modifications you have made.
-
-$CGI::Fast::VERSION='2.08';
+$CGI::Fast::VERSION='2.11';
 
 use CGI;
+use CGI::Carp;
 use FCGI;
 # use vars works like "our", but is compatible with older Perls.
 use vars qw(
